==========================
lino_book README
==========================

The documentation for Lino

Description
-----------


This is the main documentation tree about the Lino framework.  It
covers three software packages and contains example code to be used
for educational and testing purposes.

Central documentation is published at http://www.lino-framework.org



Read more on http://www.lino-framework.org
